c This is a Fortran header file: version.h
c  Modifications:
c    1/5/98, MLK: Original version
c    1/25/99, KLS: Changed screamer_version string to 2.2
c    2008-09-05 RBS: Changed the version to 3.2.4.2
c    2011-05-05 RBS: Changed the version to 3.2.5
c    2012-03-08 RBS: Changed the version to 3.2.6
c    2013-12-08 RBS: Changed the version to 3.2.7
c    2014-02-06 RBS: Changed the version to 3.3
c    2014-05-02 RBS: Changed the version to 3.3.1
c    2014-11-15 RBS: Changed the version to 4.0
c    2015-12-28 RBS: Changed the version to 4.1.4.1
c    2015-12-28 RBS: Changed the version to 4.2
c    2017-02-08 RBS: Changed the version to 4.2.3
c    2017-09-19 RBS: Changed the version to 4.2.6
c    2018-06-13 RBS: Changed the version to 4.2.7
c    2018-07-17 RBS: Changed the version to 4.2.9_beta
c    2018-07-24 RBS: Changed the version to 4.3
c
c Character strings for SCREAMER version.
c Edit this string as version changes
c
      character*(*) screamer_version
      parameter (screamer_version =
     & 'SCREAMER v4.3')
